<?php

class FrmPaymentsListHelper extends WP_List_Table {

	function FrmPaymentsListHelper() {
	    parent::__construct( array(
			'plural' => 'payments',
			'singular' => 'payment',
		) );
	}

	function ajax_user_can() {
		return current_user_can( 'administrator' );
	}

    function prepare_items() {
    	global $s, $orderby, $order, $frmdb, $frm_payment_db;

    	wp_reset_vars( array( 'action', 'name', 'submit', 'orderby', 'order', 's' ) );

    	//if ( !empty( $s ) )
    	//	$args['search'] = $s;
    	if(empty($order))
    	    $order = 'DESC';

        if(empty($orderby))
    	    $order = 'created_at';
    	    
    	$this->items = $frmdb->get_records($frm_payment_db->payments, array(), trim("$orderby $order"));
    }

    function no_items() {
    	_e( 'No payments found.' );
    }

	function get_bulk_actions() {
		$actions = array();
		$actions['delete'] = __( 'Delete' );

		return $actions;
	}


	function get_columns() {
		return array(
			'cb'        => '<input type="checkbox" />',
			'receipt_id' => __('Receipt ID'),
			'user_id'   => __('User'),
			'item_id'   => __( 'Entry' ),
			'completed' => __( 'Completed' ),
			'amount'    => __( 'Amount' ),
			'created_at' => __( 'Date' ),
			'begin_date' => __( 'Begin Date' ),
			'expire_date' => __( 'Expire Date' ),
			'paysys'    => __('Processor')
		);
	}
	

	function get_sortable_columns() {
		return array(
		    'item_id'   => 'item_id',
			'completed'  => 'completed',
			'amount'     => 'amount',
			'created_at' => 'created_at',
			'receipt_id' => 'receipt_id',
			'begin_date' => 'begin_date',
			'expire_date' => 'expire_date',
			'paysys'     => 'paysys'
		);
	}
	

    function display_rows() {
        global $frmdb;
        
    	$alt = 0;
        
        $date_format = get_option('date_format');    
        $time_format = get_option('time_format');
        $base_link = '?page=formidable-payments&action=';
        
		foreach ( $this->items as $item ) {
            $item->completed = ( $item->completed ) ? __( 'Yes' ) : __( 'No' );
            $item->amount = FrmPaymentsHelper::formatted_amount( $item->amount );
			$style = ( $alt++ % 2 ) ? '' : ' class="alternate"';

			$edit_link = $base_link .'edit&id='.$item->id;
			$view_link = $base_link .'show&id='.$item->id;
?>
    	    <tr id="payment-<?php echo $item->id; ?>" valign="middle" <?php echo $style; ?>>
<?php

    		list( $columns, $hidden ) = $this->get_column_info();

    		foreach ( $columns as $column_name => $column_display_name ) {
    			$class = "class='column-$column_name'";

    			$style = '';
    			//if ( in_array( $column_name, $hidden ) )
    			//	$style = ' style="display:none;"';

    			$attributes = $class . $style;

    			switch ( $column_name ) {
    				case 'cb':
    					echo '<th scope="row" class="check-column"><input type="checkbox" name="frm_paymentcheck[]" value="'. esc_attr( $item->id ) .'" /></th>';
    				    break;

    				case 'receipt_id':
    					echo "<td $attributes><strong><a class='row-title' href='$edit_link' title='" . __( 'Edit' ) . "'>$item->receipt_id</a></strong><br />";

    					$actions = array();
    					$actions['view'] = '<a href="' . $view_link . '">' . __( 'View' ) . '</a>';
    					$actions['edit'] = '<a href="' . $edit_link . '">' . __( 'Edit' ) . '</a>';
    					//$actions['delete'] = "<a class='submitdelete' href='" . wp_nonce_url( "link.php?action=delete&amp;link_id=$link->link_id", 'delete-bookmark_' . $link->link_id ) . "' onclick=\"if ( confirm( '" . esc_js( sprintf( __( "You are about to delete this link '%s'\n  'Cancel' to stop, 'OK' to delete." ), $link->link_name ) ) . "' ) ) { return true;}return false;\">" . __( 'Delete' ) . "</a>";
    					echo $this->row_actions( $actions );

    					echo '</td>';
    					break;
    				case 'user_id':
    				    $entry_user = $frmdb->get_var($frmdb->entries, array('id' => $item->item_id), 'user_id');
    				    
    				    if(class_exists('FrmProFieldsHelper'))
                            echo "<td $attributes>". FrmProFieldsHelper::get_display_name($entry_user, 'display_name', array('link' => true)) ."</td>";
                        else
                            echo "<td $attributes>$entry_user</td>";
                            
                        break;
    				case 'item_id':
    				    echo "<td $attributes><a href='?page=formidable-entries&action=show&id=$item->item_id'>$item->item_id</a></td>";
    					break;
    				case 'created_at':
    				case 'begin_date':
    				case 'expire_date':
    				    if(strtotime($item->{$column_name}) < 1)
    				        $item->{$column_name} = '';
    				    else if(class_exists('FrmProAppHelper'))
    				        $item->{$column_name} = FrmProAppHelper::get_formatted_time(date('Y-m-d H:i:s', strtotime($item->{$column_name})), $date_format, $time_format);
    				    
    				    ?>
					    <td <?php echo $attributes ?>><?php echo $item->{$column_name} ?></td>
					    <?php
    				    break;
    				default:
    					?>
    					<td <?php echo $attributes ?>><?php echo $item->{$column_name} ?></td>
    					<?php
    					break;
    			}
    		}
    ?>
    		</tr>
    <?php
        unset($item);
    	}
    }
}

?>